@@ -43,7 +43,6 @@ clustermq_new <- function(
 clustermq_class <- R6::R6Class(
   classname = "tar_clustermq",
   inherit = active_class,
-  class = FALSE,
   portable = FALSE,
   cloneable = FALSE,
   public = list(
@@ -73,9 +72,9 @@ clustermq_class <- R6::R6Class(
     },
     set_common_data = function(envir) {
       self$crew$set_common_data(
-        export = self$produce_exports(envir),
         fun = identity,
         const = list(),
+        export = self$produce_exports(envir),
         rettype = list(),
         pkgs = "targets",
         common_seed = 0L,
@@ -96,13 +95,13 @@ clustermq_class <- R6::R6Class(
     },
     run_worker = function(target) {
       self$crew$send_call(
-        expr = target_run_worker(target),
+        expr = target_run_worker(target, .tar_envir_5048826d),
         env = list(target = target)
       )
     },
     run_main = function(target) {
       self$crew$send_wait()
-      target_run(target)
+      target_run(target, tar_option_get("envir"))
       target_conclude(
         target,
         self$pipeline,
@@ -136,7 +135,7 @@ clustermq_class <- R6::R6Class(
     # nocov start
     wait = function() {
       self$crew$send_wait()
-      Sys.sleep(0.001)
+      self$scheduler$backoff$wait()
     },
     # nocov end
     next_target = function() {
@@ -186,7 +185,7 @@ clustermq_class <- R6::R6Class(
     },
     run_clustermq = function() {
       on.exit(try(self$crew$finalize()))
-      self$start_crew(self$pipeline$envir)
+      self$start_crew(tar_option_get("envir"))
       while (self$scheduler$progress$any_remaining()) {
         self$iterate()
       }
@@ -196,6 +195,7 @@ clustermq_class <- R6::R6Class(
     },
     run = function() {
       self$start()
+      on.exit(self$end())
       tryCatch(
         self$produce_prelocal()$run(),
         condition_prelocal = function(e) NULL
@@ -203,7 +203,6 @@ clustermq_class <- R6::R6Class(
       if (self$scheduler$queue$is_nonempty()) {
         self$run_clustermq()
       }
-      self$end()
     },
     validate = function() {
       super$validate()
