@@ -23,30 +23,30 @@ patternview_register_bytes <- function(patternview, record) {
   patternview$bytes <- patternview$bytes + record$bytes
 }
 
-patternview_register_running <- function(patternview, target, scheduler) {
-  patternview$progress <- "running"
-  scheduler$progress$write_running(target)
+patternview_register_started <- function(patternview, target, scheduler) {
+  if (identical(patternview$progress, "queued")) {
+    patternview$progress <- "started"
+    scheduler$progress$write_started(target)
+  }
 }
 
 patternview_register_canceled <- function(patternview, target, scheduler) {
-  if (!identical(patternview$progress, "errored")) {
+  if (!(patternview$progress %in% c("canceled", "errored"))) {
     patternview$progress <- "canceled"
     scheduler$progress$write_canceled(target)
   }
 }
 
 patternview_register_errored <- function(patternview, target, scheduler) {
-  patternview$progress <- "errored"
-  scheduler$progress$write_errored(target)
-}
-
-patternview_register_built <- function(patternview, target, scheduler) {
-  patternview$progress <- "built"
+  if (!identical(patternview$progress, "errored")) {
+    patternview$progress <- "errored"
+    scheduler$progress$write_errored(target)
+  }
 }
 
 patternview_register_final <- function(patternview, target, scheduler) {
-  if (identical(patternview$progress, "running")) {
-    patternview_register_built(patternview, target, scheduler)
+  if (identical(patternview$progress, "started")) {
+    patternview$progress <- "built"
     scheduler$progress$write_built(target)
   }
 }
@@ -55,6 +55,6 @@ patternview_validate <- function(patternview) {
   assert_correct_fields(patternview, patternview_new)
   assert_in(
     patternview$progress,
-    c("queued", "running", "built", "canceled", "errored")
+    c("queued", "started", "built", "canceled", "errored")
   )
 }
