@@ -1,6 +1,9 @@
-#' @title Deduplicate meta and progress databases.
+#' @title Deduplicate meta and progress databases (deprecated).
 #' @export
-#' @description Remove duplicated entries in the meta and progress
+#' @keywords internal
+#' @description Deprecated in version 0.3.0 (2020-03-06).
+#'   Deduplication happens automatically before and after the pipeline runs.
+#' @details Removes duplicated entries in the meta and progress
 #'   databases in order to lighten storage. These databases are located
 #'   in the `_targets/meta/meta` and `_targets/meta/progress` files,
 #'   and the `_targets` data store lives in the current working directory.
@@ -11,16 +14,11 @@
 #'   at `_targets/meta/meta`.
 #' @param progress Logical, whether to deduplicate the progress database file
 #'   at `_targets/meta/progress`.
-#' @examples
-#' if (identical(Sys.getenv("TAR_LONG_EXAMPLES"), "true")) {
-#' tar_dir({ # tar_dir() runs code from a temporary directory.
-#' tar_script(list(tar_target(x, 1 + 1)), ask = FALSE)
-#' tar_make()
-#' tar_make()
-#' tar_deduplicate() # Compare the file _targets/meta/meta before and after.
-#' })
-#' }
 tar_deduplicate <- function(meta = TRUE, progress = TRUE) {
+  warn_deprecate(
+    "tar_deduplicate() is deprecated in version 0.3.0 (2020-03-06). ",
+    "The tar_make*() functions do enough deduplication now automatically."
+  )
   assert_store()
   assert_lgl(meta, "meta arg of tar_deduplicate() must be logical.")
   assert_lgl(progress, "progress arg of tar_deduplicate() must be logical.")
