@@ -28,7 +28,7 @@ tar_test <- function(label, code) {
       tar_dir(testthat::test_that(label, code)),
       env = list(label = label, code = code)
     )
-    withr::local_envvar(c(TAR_ASK = "false"))
+    withr::local_envvar(c(TAR_ASK = "false", TAR_TEST = "true"))
     tar_option_reset()
     on.exit(tar_option_reset())
     tar_option_set(envir = new.env(parent = globalenv()))
