@@ -1,5 +1,5 @@
 `%||%` <- function(x, y) {
-  if (is.null(x)) {
+  if (length(x) <= 0L) {
     y
   } else {
     x
@@ -7,7 +7,7 @@
 }
 
 `%|||%` <- function(x, y) {
-  if (!length(x)) {
+  if (is.null(x)) {
     y
   } else {
     x
