@@ -15,12 +15,12 @@ tar_test("branches complete even if patterns do not", {
   tar_make() # Terminate before the second branch finishes.
   out <- tar_progress()
   expect_equal(out$progress[out$name == "x"], "built")
-  expect_equal(out$progress[out$name == "y"], "running")
+  expect_equal(out$progress[out$name == "y"], "started")
   expect_equal(out$progress[out$name == "y_bff916f9"], "built")
-  expect_equal(out$progress[out$name == "y_e15e8827"], "running")
+  expect_equal(out$progress[out$name == "y_e15e8827"], "started")
   tar_make() # The first branch should skip. Again, terminate early.
   out <- tar_progress()
   expect_equal(nrow(out), 2)
-  expect_equal(out$progress[out$name == "y"], "running")
-  expect_equal(out$progress[out$name == "y_e15e8827"], "running")
+  expect_equal(out$progress[out$name == "y"], "started")
+  expect_equal(out$progress[out$name == "y_e15e8827"], "started")
 })
