@@ -1,13 +1,13 @@
 tar_test("%||%", {
   expect_equal("x" %||% "y", "x")
-  expect_equal(character(0) %||% "y", character(0))
+  expect_equal(character(0) %||% "y", "y")
   expect_equal(NA_character_ %||% "y", NA_character_)
   expect_equal(NULL %||% "y", "y")
 })
 
 tar_test("%|||%", {
   expect_equal("x" %|||% "y", "x")
-  expect_equal(character(0) %|||% "y", "y")
+  expect_equal(character(0) %|||% "y", character(0))
   expect_equal(NA_character_ %|||% "y", NA_character_)
   expect_equal(NULL %|||% "y", "y")
 })
@@ -18,3 +18,8 @@ tar_test("%||NA%", {
   expect_equal(NA_character_ %||NA% "y", "y")
   expect_equal(NULL %||NA% "y", NULL)
 })
+
+tar_test("trn()", {
+  expect_equal(trn(TRUE, "x", "y"), "x")
+  expect_equal(trn(FALSE, "x", "y"), "y")
+})
